<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// I
	'images_description' => 'Images processing and colors filters',
	'images_slogan' => 'Images processing and colors filters',
];
